@@ -1,23 +1,27 @@
 #[macro_export]
 macro_rules! implement_cron {
     () => {
-        pub static mut CRON_STATE: Option<ic_cron::task_scheduler::TaskScheduler> = None;
+        pub static mut _CRON_STATE: Option<ic_cron::task_scheduler::TaskScheduler> = None;
 
         pub fn get_cron_state() -> &'static mut ic_cron::task_scheduler::TaskScheduler {
             unsafe {
-                match CRON_STATE.as_mut() {
+                match _CRON_STATE.as_mut() {
                     Some(cron) => cron,
                     None => {
-                        set_cron_state(ic_cron::task_scheduler::TaskScheduler::default());
+                        _put_cron_state(Some(ic_cron::task_scheduler::TaskScheduler::default()));
                         get_cron_state()
                     }
                 }
             }
         }
 
-        pub fn set_cron_state(state: ic_cron::task_scheduler::TaskScheduler) {
+        pub fn _take_cron_state() -> Option<ic_cron::task_scheduler::TaskScheduler> {
+            unsafe { _CRON_STATE.take() }
+        }
+
+        pub fn _put_cron_state(state: Option<ic_cron::task_scheduler::TaskScheduler>) {
             unsafe {
-                CRON_STATE = Some(state);
+                _CRON_STATE = state;
             }
         }
 
@@ -56,17 +60,17 @@ mod tests {
 
     #[pre_upgrade]
     fn pre_upgrade_hook() {
-        let cron_state = get_cron_state().clone();
+        let cron_state = _take_cron_state();
 
         stable_save((cron_state,)).expect("Unable to save the state to stable memory");
     }
 
     #[post_upgrade]
     fn post_upgrade_hook() {
-        let (cron_state,): (TaskScheduler,) =
+        let (cron_state,): (Option<TaskScheduler>,) =
             stable_restore().expect("Unable to restore the state from stable memory");
 
-        set_cron_state(cron_state);
+        _put_cron_state(cron_state);
     }
 
     #[heartbeat]
